@@ -27,9 +27,9 @@
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkversion.h>
 
 #include "games-files.h"
+#include "games-runtime.h"
 
 #include "games-stock.h"
 
@@ -271,7 +271,10 @@ games_stock_init (void)
     { GAMES_STOCK_NEW_GAME,         GTK_STOCK_NEW },
     { GAMES_STOCK_RESET,            GTK_STOCK_CLEAR },
     { GAMES_STOCK_RESTART_GAME,     GTK_STOCK_REFRESH },
+#if GTK_CHECK_VERSION (2, 8, 0)
+    /* This is used on hildon too, but only exists since 2.8 */
     { GAMES_STOCK_FULLSCREEN,       GTK_STOCK_FULLSCREEN },
+#endif
 #ifdef HAVE_GTK_ICON_FACTORY_ADD_ALIAS
     { GAMES_STOCK_REDO_MOVE,        GTK_STOCK_REDO },
     { GAMES_STOCK_UNDO_MOVE,        GTK_STOCK_UNDO },
@@ -313,7 +316,7 @@ games_stock_init (void)
 
   static const GtkStockItem games_stock_items[] = {
     { GAMES_STOCK_CONTENTS,         N_("_Contents"),          0, STOCK_ACCEL (GDK_F1, 0), NULL },
-    { GAMES_STOCK_FULLSCREEN,       N_("_Fullscreen"),        0, STOCK_ACCEL ('f', GDK_F6), NULL },
+    { GAMES_STOCK_FULLSCREEN,       N_("_Fullscreen"),        0, STOCK_ACCEL (GDK_F11, GDK_F6), NULL },
     { GAMES_STOCK_HINT,             N_("_Hint"),              STOCK_ACCEL (GDK_CONTROL_MASK, 0), STOCK_ACCEL ('h', GDK_Return), NULL },
     /* Translators: This "_New" is for the menu item 'Game->New', implies "New Game" */
     { GAMES_STOCK_NEW_GAME,         N_("_New"),               STOCK_ACCEL (GDK_CONTROL_MASK, 0), STOCK_ACCEL ('n', 0), NULL },
@@ -327,7 +330,7 @@ games_stock_init (void)
     { GAMES_STOCK_UNDO_MOVE,        N_("_Undo Move"),         STOCK_ACCEL (GDK_CONTROL_MASK, 0), STOCK_ACCEL ('z', GDK_F8), NULL },
     { GAMES_STOCK_DEAL_CARDS,       N_("_Deal"),              GDK_CONTROL_MASK, 'd', NULL },
 #ifndef HAVE_HILDON
-    { GAMES_STOCK_LEAVE_FULLSCREEN, N_("_Leave Fullscreen"),  0, 'f', NULL },
+    { GAMES_STOCK_LEAVE_FULLSCREEN, N_("_Leave Fullscreen"),  0, GDK_F11, NULL },
     { GAMES_STOCK_NETWORK_GAME,     N_("Network _Game"),      GDK_CONTROL_MASK, 'g', NULL },
     { GAMES_STOCK_NETWORK_LEAVE,    N_("L_eave Game"),        GDK_CONTROL_MASK, 'e', NULL },
     { GAMES_STOCK_PLAYER_LIST,      N_("Player _List"),       GDK_CONTROL_MASK, 'l', NULL },
@@ -389,14 +392,16 @@ games_stock_init (void)
    * for icons as well as the standard search paths.
    */
   /* FIXME: multi-head! */
-  gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), ICONDIR);
+  gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+                                     games_runtime_get_directory (GAMES_RUNTIME_ICON_THEME_DIRECTORY));
  
   gtk_stock_add_static (games_stock_items, G_N_ELEMENTS (games_stock_items));
 }
 
-/* Returns a GPL 2+ license string for a specific game. */
-gchar *
-games_get_license (const gchar * game_name)
+/* Returns a GPL N+ license string for a specific game. */
+static gchar *
+games_get_license_version (const gchar * game_name,
+                           int version)
 {
   gchar *license_trans, *license_str;
 
@@ -404,7 +409,7 @@ games_get_license (const gchar * game_name)
     /* %s is replaced with the name of the game in gnome-games. */
     N_("%s is free software; you can redistribute it and/or modify "
        "it under the terms of the GNU General Public License as published by "
-       "the Free Software Foundation; either version 2 of the License, or "
+       "the Free Software Foundation; either version %d of the License, or "
        "(at your option) any later version.");
   static const char license1[] =
     N_("%s is distributed in the hope that it will be useful, "
@@ -442,8 +447,21 @@ games_get_license (const gchar * game_name)
 #endif /* ! GTK+ 2.8.0 */
 
   license_str =
-    g_strdup_printf (license_trans, game_name, game_name, game_name);
+    g_strdup_printf (license_trans, game_name, version, game_name, game_name);
   g_free (license_trans);
 
   return license_str;
 }
+
+/**
+ * gamess_get_licence:
+ *
+ * Returns: a newly allocated string with a GPL licence notice. The GPL version used
+ *   depends on the game and the configure options and is determined from
+ *   games_runtime_get_gpl_version()
+ */
+gchar *
+games_get_license (const gchar * game_name)
+{
+  return games_get_license_version (game_name, games_runtime_get_gpl_version ());
+}
